<?php

/*
 * Created Dec 1, 2018 - Updated: 29.10.2020
 * HomePage: https://xentr.net
 * Copyright (c) 2019 XENTR | XenForo Add-ons - Styles -  All Rights Reserved
 */

namespace XDinc\FThread\Entity;

use XF\Mvc\Entity\Structure;

class FThread extends \XF\Mvc\Entity\Entity
{
	public function canEdit()
	{
		$thread = $this->Thread;
		$visitor = \XF::visitor();
		
		if ($visitor->hasPermission('FThread_Perm', 'ft_manage'))
		{
			return true;
		}
		
		if ($visitor->hasPermission('FThread_Perm', 'ft_submit')
			&& $visitor->user_id == $thread->user_id)
		{
			return true;
		}
		
		return false;
	}
	
	public function getImage()
	{
		$image = \XF::getRootDirectory() . '/data/FThread/' . $this->thread_id . '.jpg';
		
		if (file_exists($image))
		{
			return 'data/FThread/' . $this->thread_id . '.jpg?' . $this->fthread_time;
		}
	
		return "styles/XDinc/FThread/default.png";
	}
	
	protected function _preSave()
	{
		$this->fthread_time = \XF::$time;
	}
	
	protected function _postDelete()
	{
		$image = \XF::getRootDirectory() . '/data/FThread/' . $this->thread_id . '.jpg';
		if (file_exists($image)) { unlink($image); }
	}
	
	public static function getStructure(Structure $structure)
	{
		$structure->table = 'FThread';
		$structure->shortName = 'XDinc\FThread:FThread';
		$structure->primaryKey = 'thread_id';
		$structure->columns = [
			'thread_id' =>				['type' => self::UINT, 'required' => true],
			'fthread_date' =>			['type' => self::UINT, 'required' => true],
			'fthread_time' =>			['type' => self::UINT, 'required' => true],
			'fthread_title' =>	    	['type' => self::STR, 'required' => false, 'default' => ''],
			'fthread_content' =>		['type' => self::STR, 'required' => false, 'default' => ''],
			'fthread_media' =>			['type' => self::STR, 'required' => false, 'default' => ''],
		];
		$structure->getters = [
			'image' => true,
		];

		$structure->relations = [
			'Thread' => [
				'entity' => 'XF:Thread',
				'type' => self::TO_ONE,
				'conditions' => 'thread_id',
				'primary' => true,
			],
		];

		return $structure;
	}
}