<?php

/*
 * Created Dec 1, 2018 - Updated: 29.10.2020
 * HomePage: https://xentr.net
 * Copyright (c) 2019 XENTR | XenForo Add-ons - Styles -  All Rights Reserved
 */

namespace XDinc\FThread\Pub\Controller;

use XF\Mvc\ParameterBag;

class Thread extends XFCP_Thread

{
	public function actionIndex(ParameterBag $params)
	{
		$reply = parent::actionIndex($params);
		
		if (!$reply instanceof \XF\Mvc\Reply\View)
		{
			return $reply;
		}
		
		$thread = $reply->getParam('thread');
		
		$reply->setParam('fthread', $this->repository('XDinc\FThread:FThread')->fetchFThreadByThread($thread));
		
		return $reply;
	}

	public function actionFThreadEdit(ParameterBag $params)
	{
		if (!\XF::visitor()->hasPermission('FThread_Perm', 'ft_submit'))
		{
			return $this->noPermission();
		}
		
		$thread = $this->assertViewableThread($params->thread_id);
		$fthreadRepo = $this->repository('XDinc\FThread:FThread');
		$fthread = $fthreadRepo->fetchFThreadByThread($thread);

		if ($fthread && !$fthread->canEdit())
		{
			return $this->noPermission();
		}
		
		if ($this->isPost())
		{
			if (!$fthread)
			{
				$fthread = $this->em()->create('XDinc\FThread:FThread');
			}
			
			if ($upload = $this->request->getFile('upload', false, false))
			{
				$this->repository('XDinc\FThread:FThread')->setFThreadFromUpload($thread, $upload);
			}
			
			$input = $this->filter('fthread', 'array');
			$input['thread_id'] = $thread->thread_id;
			$input['fthread_title'] = !empty($input['fthread_title']) ? $input['fthread_title'] : '';
			$input['fthread_content'] = !empty($input['fthread_content']) ? $input['fthread_content'] : '';
			
			$date = $this->filter('date', 'datetime');
			$time = $this->filter('time', 'str');
			list ($hour, $min) = explode(':', $time);
			
			$dateTime = new \DateTime('@'.$date);
			$dateTime->setTimeZone(\XF::language()->getTimeZone());
			$dateTime->setTime($hour, $min);
			$input['fthread_date'] = $dateTime->getTimestamp();
			
			$form = $this->formAction();
			$form->basicEntitySave($fthread, $input);
			$form->run();
			
			return $this->redirect($this->buildLink('threads', $thread));
		}
		
		$viewParams = [
			'thread' => $thread,
			'fthread' => $fthread,
		];
		
		return $this->view('XDinc\FThread:Thread\FThreadEdit', 'xtr_fthread_edit', $viewParams);
	}
	
	public function actionFThreadDelete(ParameterBag $params)
	{
		$fthread = $this->assertFThreadExists($params->thread_id, 'Thread');
		
		if (!$fthread->canEdit())
		{
			return $this->noPermission();
		}
		
		if (!$fthread->preDelete())
		{
			return $this->error($fthread->getErrors());
		}

		if ($this->isPost())
		{
			$fthread->delete();
			return $this->redirect($this->buildLink('threads', $fthread));
		}
		else
		{
			$viewParams = [
				'fthread' => $fthread
			];
			return $this->view('XDinc\FThread:FThread\Delete', 'xtr_fthread_delete', $viewParams);
		}
	}	
	
	protected function assertFThreadExists($id, $with = null, $phraseKey = null)
	{
		return $this->assertRecordExists('XDinc\FThread:FThread', $id, $with, $phraseKey);
	}
}