<?php

/*
 * Created Dec 1, 2018 - Updated: 29.10.2020
 * HomePage: https://xentr.net
 * Copyright (c) 2019 XENTR | XenForo Add-ons - Styles -  All Rights Reserved
 */

namespace XDinc\FThread\Repository;

use XF\Mvc\Entity\AbstractCollection;
use XF\Mvc\Entity\Repository;

class FThread extends Repository
{
	public function findFThread()
	{
		return $this->finder('XDinc\FThread:FThread')
			->with('Thread', true)
			->with('Thread.FirstPost', true)
			->order('fthread_date', 'DESC');
	}
	
	public function fetchFThreadByThread($thread)
	{
		return $this->finder('XDinc\FThread:FThread')
			->where('thread_id', $thread->thread_id)
			->fetchOne();
	}
	
	public function parseFThreads($fthreads, $trim = 0)
	{
		foreach ($fthreads AS &$fthread)
		{
			$fthread = $this->parseFThread($fthread, $trim);
		}
		
		return $fthreads;
	}
	
	public function parseFThread($fthread, $trim = 0)
	{

   	$options = \XF::options();
        $trim = \XF::options()->FThread_Limit;


		if (empty($fthread->fthread_content))
		{
			$fthread->fthread_content = $fthread->Thread->FirstPost->message;
		}
		
		$fthread->fthread_content = str_replace(["\r","\n"], ' ', $fthread->fthread_content);
		
		$formatter = \XF::app()->stringFormatter();
		$fthread->fthread_content = $formatter->snippetString($fthread->fthread_content, $trim, ['stripBbCode' => true]);
		
		return $fthread;
	}
	
	public function setFThreadFromUpload($thread, $upload)
	{
		$upload->requireImage();

		if (!$upload->isValid($errors))
		{
			throw new \XF\PrintableException(reset($errors));
		}
		
		$target = 'data://FThread/'.$thread->thread_id.'.jpg';
		$dimensions = \XF::options()->FThread_Size;
		$width = $dimensions['width'];
		$height = $dimensions['height'];
			
		try
		{
			$image = \XF::app()->imageManager->imageFromFile($upload->getTempFile());
			
			$ratio = $width / $height;
			$w = $image->getWidth();
			$h = $image->getHeight();
			
			if ($w / $h > $ratio)
			{
				$image->resizeTo($w * ($height / $h), $height);
			}
			else
			{
				$image->resizeTo($width, $h * ($width / $w));
			}

			$w = $image->getWidth();
			$h = $image->getHeight();
			$offWidth = ($w - $width) / 2;
			$offHeight = ($h - $height) / 2;

			$image->crop($width, $height, $offWidth, $offHeight);
			
			$tempFile = \XF\Util\File::getTempFile();
			if ($tempFile && $image->save($tempFile))
			{
				$output = $tempFile;
			}
			unset($image);
			
			\XF\Util\File::copyFileToAbstractedPath($output, $target);
		}
		catch (Exception $e)
		{
			throw new \XF\PrintableException(\XF::phrase('FThread_warning'));
		}
	}
}